package Bencher::ScenarioR::CPANInstallers::cpanm_local;

our $VERSION = 0.003; # VERSION

our $results = [];

1;
# ABSTRACT: Benchmark installing modules from a local mirror using cpanm

=head1 DESCRIPTION

This module is automatically generated by Pod::Weaver::Plugin::Bencher::Scenario during distribution build.

A Bencher::ScenarioR::* module contains the raw result of sample benchmark and might be useful for some stuffs later.

